Learn R Programming

fulltext (version 1.0.1)

fulltext-defunct: Defunct functions in fulltext

Description

  • ft_extract_corpus Function removed. As part of focusing scope of the package we're trying to limit dependencies, so downstream use of tm can still easily be done.

  • pdfx: Function removed. We're trying to focus the scope of the package - and this function is more out of scope now.

  • chunks: Function name changed to ft_chunks()

  • tabularize: Function name changed to ft_tabularize()

  • collect: Function name changed to ft_collect()

  • get_text: Function name changed to ft_text()

  • cache_clear was never working anyway, and is now removed

Arguments