fulltext.RdLeightweight fulltext display htmlwidget and corresponding functionality.
fulltext(data, width = NULL, height = NULL, dialog = NULL, box = TRUE)
| data | The data that is passed to the JavaScript that generates the output. Expected to be
a list of lists that provide data on sections of text. Each of the sub-lists is to be a named
list of a character vector with the HTML element the section will be wrapped into, and
a |
|---|---|
| width | The width of the widget. |
| height | The height of the widget. |
| dialog | The dialog. |
| box | Logical, whether to put text into a box. |